@@ -8,11 +8,11 @@
 
 #include <QDebug>
 
-#include "webviewwindow.h"
-#include "graphicsviewwindow.h"
+// #include "webviewwindow.h"
+#include "mainwindow.h"
 #include "bookmark.h"
 
-#define CURRENT_APP_VERSION 14
+#define CURRENT_APP_VERSION 15
 #define APPFOLDER "/home/user/.macuco/"
 #ifndef QT_NO_DEBUG_OUTPUT
     #define LOGFILE "/home/user/.macuco/log.txt"
@@ -103,27 +103,27 @@ int Application::execute() {
     }
 #endif
 
-    loadSettings();
+    int version = loadSettings();
+    if ( version<CURRENT_APP_VERSION ) {
+        qDebug() << "Upgrading from " + QString::number(version) + " to " + QString::number(CURRENT_APP_VERSION);
+        aboutMacuco();
+
+        // save settings (finish upgrade)
+        saveSettings();
+    }
 
 #ifndef Q_WS_MAEMO_5
     start();
 #endif
 
     int res = exec();
-
     saveSettings();
 
     return res;
 }
 
 MainWindow* Application::newWindow() {
-
-#ifdef Q_WS_MAEMO_5
-    // GraphicsViewWindow *pMainWindow = new GraphicsViewWindow(m_pMainWindow);
-    WebViewWindow *pMainWindow = new WebViewWindow(m_pMainWindow);
-#else
-    WebViewWindow *pMainWindow = new WebViewWindow(m_pMainWindow);
-#endif
+    MainWindow *pMainWindow = new MainWindow(m_pMainWindow);
 
     if ( m_pMainWindow ) {
         pMainWindow->setAttribute(Qt::WA_DeleteOnClose);
@@ -160,6 +160,7 @@ void Application::start() {
         m_pMainWindow->show();
         m_pMainWindow->activateWindow();
         m_pMainWindow->raise();
+        // m_pMainWindow->goHome();
         return;
     }
 
@@ -188,7 +189,7 @@ void Application::visitUrl(QString url, bool fakeAgent) {
     pWindow->raise();
 }
 
-void Application::loadSettings() {
+int Application::loadSettings() {
     qDebug() << "load settings";
     qDebug() << "Version: " << QString::number(CURRENT_APP_VERSION);
 
@@ -217,10 +218,7 @@ void Application::loadSettings() {
 
     qDebug() << ">> done loading settings";
 
-    if ( version<CURRENT_APP_VERSION ) {
-        qDebug() << "Upgrading from " + QString::number(version) + " to " + QString::number(CURRENT_APP_VERSION);
-        aboutMacuco();
-    }
+    return version;
 }
 
 void Application::saveSettings() {
