@@ -38,6 +38,7 @@
 
 #include "fullscreenexitbutton.h"
 #include "waitingbutton.h"
+#include "qwebviewselectionsuppressor.h"
 
 #include "gotodlg.h"
 #include "bookmark.h"
@@ -50,7 +51,7 @@ MainWindow::MainWindow(MainWindow *pParent) :
 #ifdef Q_WS_MAEMO_5
     m_pOrientationSelector(NULL), m_pUserAgentSelector(NULL),
 #endif
-    m_pBookmarks(NULL), m_pFullscreenAction(NULL), m_pWaitingButton(NULL)
+    m_pBookmarks(NULL), m_pFullscreenAction(NULL), m_pWaitingButton(NULL), m_pWebView(NULL)
 {
     setWindowTitle("Macuco");
 
@@ -97,6 +98,27 @@ MainWindow::MainWindow(MainWindow *pParent) :
 #ifdef Q_WS_MAEMO_5
     m_pWaitingButton = new WaitingButton(this);
 #endif
+
+    m_pWebView = new QWebView(this);
+
+    connect(m_pWebView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
+    connect(m_pWebView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
+    connect(m_pWebView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
+
+#ifdef Q_WS_MAEMO_5
+    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
+    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
+
+    new QWebViewSelectionSuppressor(m_pWebView);
+#endif
+
+    m_pWebView->setPage(&m_webPage);
+    setCentralWidget(m_pWebView);
+
+    // cancel
+    if (m_pWaitingButton) connect(m_pWaitingButton, SIGNAL(clicked()), m_pWebView, SLOT(stop()));
+
+    startUp();
 }
 
 void MainWindow::startUp() {
@@ -118,36 +140,6 @@ void MainWindow::startUp() {
         setOrientation(app.m_orientation);
     }
 
-    /*
-    if ( m_pParent ) {
-        // copy settings from mainwindow
-        m_zoomFactor = m_pParent->m_zoomFactor;
-        //m_pBookmarks = m_pParent->m_pBookmarks;
-        setFullScreen(m_pParent->isFullScreen());
-        setUserAgent( m_pParent->m_webPage.isIphoneUserAgent() );
-
-#ifdef Q_WS_MAEMO_5
-        qDebug() << "New Window: " << m_pParent->isLandscape() << " - " << m_pParent->isAutoRotate();
-        setAutoRotate(false);
-        setLandscape(m_pParent->isLandscape());
-#endif
-
-    } else {
-
-        m_pBookmarks = new QList<Bookmark>();
-
-        // load settings
-        loadSettings();
-    }
-    */
-
-#ifdef Q_WS_X11
-#ifndef Q_WS_MAEMO_5
-    // meego?
-    setGeometry(QRect(QPoint(0,0),QApplication::desktop()->size()));
-#endif
-#endif
-
     createMenu();
     updateTitle();
 }
@@ -322,18 +314,7 @@ void MainWindow::hideLoading(bool success) {
 }
 
 void MainWindow::changeUrl(QUrl url) {
-    /*
-    QIcon icon = m_webPage.settings()->iconForUrl(url);
-    qDebug() << icon.isNull();
-    */
-
     m_currentUrl = url;
-
-    /*
-#ifndef Q_WS_MAEMO_5
-    m_pToolbar->getInputAddress()->setText( url.toString() );
-#endif
-    */
 }
 
 void MainWindow::visitUrl(QString url) {
@@ -384,17 +365,41 @@ void MainWindow::resizeEvent(QResizeEvent* pEvent) {
 
 void MainWindow::closeEvent(QCloseEvent *pEvent)
 {
+    pEvent->accept();
+
+    /*
 #ifdef Q_WS_MAEMO_5
     grabZoomKeys(false);
 #endif
+    */
 
-    if ( !m_pParent ) {
-        // top most
-        // saveSettings();
-        m_webPage.saveCookies();
+    if ( m_pParent ) return;
+
+    // top most
+    m_webPage.saveCookies();
+    if ( !m_pWebView ) return;
+
+    QString url = m_pWebView ? m_pWebView->url().toString() : QString::null;
+    QString html =
+        "<HTML><HEAD><TITLE>Macuco</TITLE>"
+        "<style type=\"text/css\">TD.link {text-align:center; height: 50px; background-color: #ffccaa; border: 2px solid black; }</style>"
+        "<BODY style='font-size:14pt; font-family: Verdana;text-aling:center;'>"
+        "<table style='width:100%;'>"
+        "<tr><td><b>Quick Links</b></td></tr>";
+        "<tr><td class='link' onclick='document.location.href=\"" + url + "\"'>" + m_pWebView->title() + "</td></tr>"
+        "<tr><td class='link' onclick='document.location.href=\"http://www.crochik.com/macuco\"'>Macuco Home</td></tr>"
+        "<tr><td class='link' onclick='document.location.href=\"http://www.crochik.com/macuco2/latest.html\"'>About/FAQ/Donate</td></tr>";
+
+    if ( m_pBookmarks ) {
+        html += "<tr><td><b>Bookmarks</b></td></tr>";
+        foreach ( Bookmark bookmark, *m_pBookmarks ) {
+            html += "<tr><td class='link' onclick='document.location.href=\"" + bookmark.url() + "\"'>" + bookmark.title() + "</td></tr>";
+        }
     }
 
-    pEvent->accept();
+    html += "</table></BODY></HTML>";
+    m_webPage.mainFrame()->setHtml(html);
+
 }
 
 void MainWindow::zoomIn() {
@@ -404,7 +409,6 @@ void MainWindow::zoomIn() {
 void MainWindow::zoomOut() {
     setZoom(m_zoomFactor/1.15);
 }
-
 void MainWindow::setZoom(qreal zoomFactor) {
     enableWebkitAutoSize();
     m_zoomFactor = zoomFactor;
@@ -417,6 +421,10 @@ void MainWindow::setZoom(qreal zoomFactor) {
     m_webPage.setPreferredContentsSize(sz.toSize());
 
     updateTitle();
+
+    Q_ASSERT(m_pWebView);
+    if ( !m_pWebView ) return;
+    m_pWebView->setZoomFactor(m_zoomFactor);
 }
 
 void MainWindow::keyPressEvent(QKeyEvent *event)
@@ -459,6 +467,12 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
             if ( (event->modifiers()&Qt::ControlModifier) != Qt::ControlModifier  ) break;
             zoomFit();
             break;
+
+        case Qt::Key_R:
+            if ( (event->modifiers()&Qt::ControlModifier) != Qt::ControlModifier  ) break;
+            if ( m_pWebView ) m_pWebView->reload();
+            break;
+
     }
 }
 
@@ -728,4 +742,18 @@ bool MainWindow::setViewport() {
     return false;
 }
 
+void MainWindow::updateTitle() {
+    QString title = m_currentUrl.isEmpty() || !m_pWebView ? "Macuco" : m_pWebView->title();
 
+#ifndef Q_WS_MAEMO_5
+    if ( m_webPage.isIphoneUserAgent() ) title += " - iPhone";
+    title += QString(" - %1%").arg(QString::number(m_zoomFactor*100, 'f', 0));
+#endif
+
+    setWindowTitle(title);
+}
+
+void MainWindow::visitUrl(QUrl url) {
+    Q_ASSERT(m_pWebView);
+    m_pWebView->load(url);
+}
