@@ -56,9 +56,9 @@ public:
     void setUserAgent(bool iphone=true);
 
 protected:
-    virtual void updateTitle()=0;
-    virtual void visitUrl(QUrl)=0;
-    virtual void setZoom(qreal zoomFactor);
+    void updateTitle();
+    void visitUrl(QUrl);
+    void setZoom(qreal zoomFactor);
 
 protected:
     void startUp();
@@ -120,7 +120,7 @@ protected slots:
 #endif
 
 protected:
-    // mainWindow components
+    QWebView        *m_pWebView;
     QUrl            m_currentUrl;
     qreal           m_zoomFactor;
     QStringList     m_errors;
