@@ -1,3 +1,21 @@
+/*
+ * Copyright 2010 Felipe Crochik <foss@crochik.com>
+ * All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "webview.h"
 #include "mainwindow.h"
 
@@ -209,8 +227,8 @@ void WebView::mouseMoveEvent(QMouseEvent *pEvent) {
                 if (m_timeStamp.elapsed() > 100) {
                     //qDebug() << ">> elapsed()>100?";
                     m_timeStamp = QTime::currentTime();
-                    m_speed = delta - delta;
-                    delta = delta;
+                    m_speed = delta - m_delta;
+                    m_delta = delta;
                 }
             }
             break;
@@ -281,8 +299,8 @@ void WebView::mouseReleaseEvent(QMouseEvent *pEvent) {
             if (m_timeStamp.elapsed() > 100) {
                 //qDebug() << ">> elapsed>100: ????";
                 m_timeStamp = QTime::currentTime();
-                m_speed = delta - delta;
-                delta = delta;
+                m_speed = delta - m_delta;
+                m_delta = delta;
             }
 
             m_offset = scrollOffset();
